@@ -9,7 +9,10 @@ from typing import Any, Callable
 
 import matplotlib.pyplot as plt
 import pandas as pd
+from matplotlib.axes import Axes
 from matplotlib.collections import PatchCollection
+from matplotlib.colorbar import Colorbar
+from matplotlib.colors import Colormap, Normalize
 from matplotlib.figure import Figure
 from matplotlib.patches import Patch
 from matplotlib.projections.polar import PolarAxes
@@ -88,6 +91,7 @@ class Circos:
         self._rad_lim = (math.radians(start), math.radians(end))
         self._patches: list[Patch] = []
         self._plot_funcs: list[Callable[[PolarAxes], None]] = []
+        self._ax: PolarAxes | None = None
         self._show_axis_for_debug = show_axis_for_debug
 
     ############################################################
@@ -128,6 +132,17 @@ class Circos:
                 tracks.append(track)
         return tracks
 
+    @property
+    def ax(self) -> PolarAxes:
+        """Plot polar axes
+
+        Can't access `ax` property before calling `circos.plotfig()` method
+        """
+        if self._ax is None:
+            err_msg = "Can't access ax property before calling `circos.plotfig() method"
+            raise ValueError(err_msg)
+        return self._ax
+
     ############################################################
     # Public Method
     ############################################################
@@ -148,6 +163,7 @@ class Circos:
         label_kws: dict[str, Any] = {},
         ticks_kws: dict[str, Any] = {},
         link_kws: dict[str, Any] = {},
+        link_kws_handler: Callable[[str, str], dict[str, Any] | None] | None = None,
     ) -> Circos:
         """Initialize Circos instance from Matrix
 
@@ -190,6 +206,11 @@ class Circos:
         link_kws : dict[str, Any], optional
             Keyword arguments passed to `circos.link()` method
             (e.g. `dict(direction=1, ec="black", lw=0.5, alpha=0.8, ...)`)
+        link_kws_handler : Callable[[str, str], dict[str, Any] | None] | None, optional
+            User-defined function to handle keyword arguments for each link.
+            This option allows user to set or override properties such as
+            `fc`, `alpha`, `zorder`, etc... on each link.
+            Handler function arguments `[str, str]` means `[from_label, to_label]`.
 
         Returns
         -------
@@ -233,11 +254,19 @@ class Circos:
         for link in matrix.to_links():
             from_label, to_label = link[0][0], link[1][0]
             fromto_label = f"{from_label}{to_label}"
+            # Set link color
             if fromto_label in fromto_label2color:
                 color = fromto_label2color[fromto_label]
             else:
                 color = name2color[from_label]
-            circos.link(*link, fc=color, **link_kws)
+            # Update link properties by user-defined handler function
+            _link_kws = deepcopy(link_kws)
+            _link_kws.update(fc=color)
+            if link_kws_handler is not None:
+                handle_link_kws = link_kws_handler(from_label, to_label)
+                if handle_link_kws is not None:
+                    _link_kws.update(handle_link_kws)
+            circos.link(*link, **_link_kws)
 
         return circos
 
@@ -343,7 +372,7 @@ class Circos:
 
         Parameters
         ----------
-        sector_names : list[str]
+        group_sector_names : list[str]
             Group sector names
 
         Returns
@@ -554,6 +583,54 @@ class Circos:
         )
         self._patches.append(bezier_curve)
 
+    def colorbar(
+        self,
+        bounds: tuple[float, float, float, float] = (1.02, 0.3, 0.02, 0.4),
+        *,
+        vmin: float = 0,
+        vmax: float = 1,
+        cmap: str | Colormap = "bwr",
+        orientation: str = "vertical",
+        colorbar_kws: dict[str, Any] = {},
+        tick_kws: dict[str, Any] = {},
+    ) -> None:
+        """Plot colorbar
+
+        Parameters
+        ----------
+        bounds : tuple[float, float, float, float], optional
+            Colorbar bounds tuple (`x`, `y`, `width`, `height`)
+        vmin : float, optional
+            Colorbar min value
+        vmax : float, optional
+            Colorbar max value
+        cmap : str | Colormap, optional
+            Colormap (e.g. `viridis`, `Spectral`, `Reds`, `Greys`)
+            <https://matplotlib.org/stable/tutorials/colors/colormaps.html>
+        orientation : str, optional
+            Colorbar orientation (`vertical`|`horizontal`)
+        colorbar_kws : dict[str, Any], optional
+            Colorbar properties (e.g. `dict(label="name", format="%.1f", ...)`)
+            <https://matplotlib.org/stable/api/colorbar_api.html>
+        tick_kws : dict[str, Any], optional
+            Axes.tick_params properties (e.g. `dict(labelsize=12, colors="red", ...)`)
+            <https://matplotlib.org/stable/api/_as_gen/matplotlib.axes.Axes.tick_params.html>
+        """
+
+        def plot_colorbar(ax: PolarAxes) -> None:
+            axin: Axes = ax.inset_axes(bounds)
+            norm = Normalize(vmin=vmin, vmax=vmax)
+            Colorbar(
+                axin,
+                cmap=cmap,
+                norm=norm,
+                orientation=orientation,
+                **colorbar_kws,
+            )
+            axin.tick_params(**tick_kws)
+
+        self._plot_funcs.append(plot_colorbar)
+
     def plotfig(
         self,
         dpi: int = 100,
@@ -691,6 +768,7 @@ class Circos:
 
         show_axis = "on" if self._show_axis_for_debug else "off"
         ax.axis(show_axis)
+        self._ax = ax
 
     def _get_all_patches(self) -> list[Patch]:
         """Get all patches from `circos, sector, track`
